@@ -5,13 +5,15 @@ import requests
 from os import path
 from .decorators import classorinstancemethod
 from .search import bin_search, SearchType, SortOrder, NotFoundBehavior
+from enum import Enum
 
 
-class JsonParseBehavior:
+class JsonParseBehavior(Enum):
     RaiseError = 0
     IgnoreNewAttributes = 1
     IncorporateNewAttributes = 2
 
+
 class JsonDate:
     """
     A utility class representing date format configurations for JSON serialization and deserialization.
@@ -56,8 +58,6 @@ class JsonObject:
         """
         s = ""
         for k in self.get_members():
-            if k[0] == "_":
-                continue
             if s:
                 s += ","
             s += "\"%s\":" % k
@@ -146,7 +146,8 @@ class JsonObject:
                     columns.append(v)
         return columns
 
-    def into(self, cls: type):
+    def into(self, cls: type,
+             behavior: JsonParseBehavior = JsonParseBehavior.RaiseError):
         """
         Convert the current JsonObject into an instance of another JsonObject-derived class.
 
@@ -161,7 +162,7 @@ class JsonObject:
         """
         if not issubclass(cls, JsonObject):
             raise RuntimeError("type must derive from JsonObject")
-        nv = cls.parse(str(self))
+        nv = cls.parse(json_string=str(self), behavior=behavior)
         return nv
 
     def get_columns(self):
@@ -259,7 +260,7 @@ class JsonObject:
         members = []
         v = vars(self)
         for k in v:
-            if k[0] == "_":
+            if not k or k[0] == "_":
                 continue
             members.append(k)
         return members
@@ -837,7 +838,12 @@ class JsonList(list):
         else:
             return None
 
-    def find_ordered(self, value, key=None, search_type=SearchType.Exact, order=SortOrder.Ascending, not_found_behavior=NotFoundBehavior.RaiseError):
+    def find_ordered(self,
+                     value,
+                     key=None,
+                     search_type: SearchType = SearchType.Exact,
+                     order: SortOrder = SortOrder.Ascending,
+                     not_found_behavior: NotFoundBehavior = NotFoundBehavior.RaiseError):
         """
         Search for an item in an ordered list.
 
@@ -854,7 +860,12 @@ class JsonList(list):
         i = bin_search(self, value, key=key, search_type=search_type, order=order, not_found_behavior=not_found_behavior)
         return None if i is None else self[i]
 
-    def find_ordered_index(self, value, key=None, search_type=SearchType.Exact, order=SortOrder.Ascending, not_found_behavior=NotFoundBehavior.RaiseError):
+    def find_ordered_index(self,
+                           value,
+                           key=None,
+                           search_type: SearchType = SearchType.Exact,
+                           order: SortOrder = SortOrder.Ascending,
+                           not_found_behavior: NotFoundBehavior = NotFoundBehavior.RaiseError):
         """
         Search for the index of an item in an ordered list.
 
@@ -868,7 +879,12 @@ class JsonList(list):
         Returns:
         int or None: The index of the found item or None based on the NotFoundBehavior.
         """
-        return bin_search(self, value, key=key, search_type=search_type, order=order, not_found_behavior=not_found_behavior)
+        return bin_search(self,
+                          value,
+                          key=key,
+                          search_type=search_type,
+                          order=order,
+                          not_found_behavior=not_found_behavior)
 
     def process(self, l):
         """
